@@ -741,6 +741,11 @@ XPoint UGetCursor()
    u_int   nullui;
    XPoint newpos;
  
+   if (areawin->area == NULL) {
+      newpos.x = newpos.y = 0;
+      return newpos;
+   }
+
 #ifdef TCL_WRAPPER
    /* Don't use areawin->window;  if called from inside an object	*/
    /* (e.g., "here" in a Tcl expression), areawin->window will be	*/
@@ -771,7 +776,11 @@ XPoint UGetCursorPos()
 {
    XPoint winpos, userpos;
  
-   winpos = UGetCursor();
+   if (areawin->area == NULL) {
+      winpos.x = winpos.y = 0;
+   }
+   else
+      winpos = UGetCursor();
 
    window_to_user(winpos.x, winpos.y, &userpos);  
 
@@ -1002,13 +1011,7 @@ short flipadjust(short anchor)
          if ((tmpanchor & (RIGHT | NOTLEFT)) != NOTLEFT)
             tmpanchor ^= (RIGHT | NOTLEFT);
 
-	 /* Right justification of flipped text becomes left justification */
-	 /* and vice versa.						   */
-
-         if (tmpanchor & JUSTIFYRIGHT)
-            tmpanchor &= (~JUSTIFYRIGHT);
-         else if ((tmpanchor & (JUSTIFYBOTH | JUSTIFYRIGHT | TEXTCENTERED)) == 0)
-            tmpanchor |= (JUSTIFYRIGHT);
+	 /* NOTE:  Justification does not change under flip invariance.	*/
       }   
       if ((DCTM)->e > EPS) {
          if ((tmpanchor & (TOP | NOTBOTTOM)) != NOTBOTTOM) 
@@ -1127,7 +1130,9 @@ void UPopCTM()
    areawin->MatStack = lastmatrix;
 
 #ifdef HAVE_CAIRO
-   xc_cairo_set_matrix(lastmatrix);
+   if (areawin->area) {
+      xc_cairo_set_matrix(lastmatrix);
+   }
 #endif /* HAVE_CAIRO */
 }
 
@@ -2125,9 +2130,9 @@ void UDrawTextLine(labelptr curlabel, short tpos)
 
    points[0].x = (tmpanchor & NOTLEFT ?
         (tmpanchor & RIGHT ? -maxwidth : -maxwidth >> 1) : 0) + tmpext.width;
-   if (tmpanchor & JUSTIFYRIGHT)
+   if ((tmpanchor & JUSTIFYRIGHT) && tlinfo.padding)
       points[0].x += tlinfo.padding[tlinfo.line];
-   else if (tmpanchor & TEXTCENTERED)
+   else if ((tmpanchor & TEXTCENTERED) && tlinfo.padding)
       points[0].x += 0.5 * tlinfo.padding[tlinfo.line];
    points[0].y = (tmpanchor & NOTBOTTOM ?
         (tmpanchor & TOP ? -tmpext.ascent : -(tmpext.ascent + xbase) / 2)
