@@ -152,6 +152,8 @@ static XtResource resources[] = {
 
   { "bboxcolor", "BBoxColor", XtRPixel, sizeof(Pixel),
       XtOffset(ApplicationDataPtr, bboxpix), XtRString, "greenyellow"},
+  { "fixedbboxcolor", "FixedBBoxColor", XtRPixel, sizeof(Pixel),
+      XtOffset(ApplicationDataPtr, fixedbboxpix), XtRString, "Pink"},
   { "clipcolor", "ClipColor", XtRPixel, sizeof(Pixel),
       XtOffset(ApplicationDataPtr, clipcolor), XtRString, "powderblue"},
 
@@ -539,7 +541,7 @@ void createmenus (xcWidget form, xcWidget *firstbutton, xcWidget *lastbutton)
 /* Check for conditions to approve program exit */
 /*----------------------------------------------*/
 
-void quitcheck(xcWidget w, caddr_t clientdata, caddr_t calldata)
+int quitcheck(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
    char *promptstr;
    Boolean doprompt = False;
@@ -564,10 +566,12 @@ void quitcheck(xcWidget w, caddr_t clientdata, caddr_t calldata)
       savebutton = getgeneric(w, quitcheck, NULL);
       popupprompt(w, promptstr, NULL, quit, savebutton, NULL);
       free(promptstr);
+      return 0;
    }
    else {
       free(promptstr);
       quit(areawin->area, NULL);
+      return 1;
    }
 }
 
@@ -1700,7 +1704,7 @@ XCWindowData *GUI_init(int argc, char *argv[])
    XtnSetArg(XtNxAddWidth, True);
    XtnSetArg(XtNxAttachRight, True);
    XtnSetArg(XtNheight, ROWHEIGHT);
-   sprintf(_STR, "   Welcome to Xcircuit Version %2.1f", PROG_VERSION);
+   sprintf(_STR, "   Welcome to Xcircuit Version %s", PROG_VERSION);
    XtnSetArg(XtNstring, _STR);
    XtnSetArg(XtNxResizable, True);
    XtnSetArg(XtNgravity, WestGravity);
